summaryrefslogtreecommitdiff
path: root/src/dropbox-command-client.h
diff options
context:
space:
mode:
authorBenjamin Valentin <[email protected]>2012-03-27 03:10:35 +0200
committerBenjamin Valentin <[email protected]>2012-03-27 03:10:35 +0200
commitf05bcc640f666acf756e7501ceefe1ad3cbf7e64 (patch)
tree85dab17a828f45f2897b9eff6883258de584e566 /src/dropbox-command-client.h
parente214b332395adbc77ad596218895a4834cad434d (diff)
downloadcaja-dropbox-f05bcc640f666acf756e7501ceefe1ad3cbf7e64.tar.bz2
caja-dropbox-f05bcc640f666acf756e7501ceefe1ad3cbf7e64.tar.xz
run migrate script
Diffstat (limited to 'src/dropbox-command-client.h')
-rw-r--r--src/dropbox-command-client.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/dropbox-command-client.h b/src/dropbox-command-client.h
index c1ea3bc..a06f777 100644
--- a/src/dropbox-command-client.h
+++ b/src/dropbox-command-client.h
@@ -2,45 +2,45 @@
* Copyright 2008 Evenflow, Inc.
*
* dropbox-command-client.h
* Header file for nautilus-dropbox-command.c
*
* This file is part of nautilus-dropbox.
*
* nautilus-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* nautilus-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
#ifndef DROPBOX_COMMAND_CLIENT_H
#define DROPBOX_COMMAND_CLIENT_H
-#include <libnautilus-extension/nautilus-info-provider.h>
-#include <libnautilus-extension/nautilus-file-info.h>
+#include <libcaja-extension/caja-info-provider.h>
+#include <libcaja-extension/caja-file-info.h>
G_BEGIN_DECLS
/* command structs */
-typedef enum {GET_FILE_INFO, GENERAL_COMMAND} NautilusDropboxRequestType;
+typedef enum {GET_FILE_INFO, GENERAL_COMMAND} CajaDropboxRequestType;
typedef struct {
- NautilusDropboxRequestType request_type;
+ CajaDropboxRequestType request_type;
} DropboxCommand;
typedef struct {
DropboxCommand dc;
- NautilusInfoProvider *provider;
+ CajaInfoProvider *provider;
GClosure *update_complete;
- NautilusFileInfo *file;
+ CajaFileInfo *file;
gboolean cancelled;
} DropboxFileInfoCommand;
@@ -51,13 +51,13 @@ typedef struct {
GHashTable *emblems_response;
} DropboxFileInfoCommandResponse;
-typedef void (*NautilusDropboxCommandResponseHandler)(GHashTable *, gpointer);
+typedef void (*CajaDropboxCommandResponseHandler)(GHashTable *, gpointer);
typedef struct {
DropboxCommand dc;
gchar *command_name;
GHashTable *command_args;
- NautilusDropboxCommandResponseHandler handler;
+ CajaDropboxCommandResponseHandler handler;
gpointer handler_ud;
} DropboxGeneralCommand;
@@ -90,7 +90,7 @@ void dropbox_command_client_send_simple_command(DropboxCommandClient *dcc,
const char *command);
void dropbox_command_client_send_command(DropboxCommandClient *dcc,
- NautilusDropboxCommandResponseHandler h,
+ CajaDropboxCommandResponseHandler h,
gpointer ud,
const char *command, ...);
void
@@ -2,45 +2,45 @@
*
* dropbox-command-client.h
- * Header file for nautilus-dropbox-command.c
+ * Header file for caja-dropbox-command.c
*
@@ -2,45 +2,45 @@
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
@@ -2,45 +2,45 @@
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -2,45 +2,45 @@
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the